@@ -51,6 +51,7 @@ struct _TrackerPropertyPrivate {
 	gint           weight;
 	gint           id;
 	gboolean       indexed;
+	TrackerProperty *secondary_index;
 	gboolean       fulltext_indexed;
 	gboolean       fulltext_no_limit;
 	gboolean       embedded;
@@ -60,6 +61,7 @@ struct _TrackerPropertyPrivate {
 	gboolean       is_new;
 	gboolean       db_schema_changed;
 	gboolean       writeback;
+	gchar         *default_value;
 
 	GArray        *super_properties;
 };
@@ -155,8 +157,14 @@ property_finalize (GObject *object)
 		g_object_unref (priv->range);
 	}
 
+	if (priv->secondary_index) {
+		g_object_unref (priv->secondary_index);
+	}
+
 	g_array_free (priv->super_properties, TRUE);
 
+	g_free (priv->default_value);
+
 	(G_OBJECT_CLASS (tracker_property_parent_class)->finalize) (object);
 }
 
@@ -311,6 +319,18 @@ tracker_property_get_indexed (TrackerProperty *property)
 	return priv->indexed;
 }
 
+TrackerProperty *
+tracker_property_get_secondary_index (TrackerProperty *property)
+{
+	TrackerPropertyPrivate *priv;
+
+	g_return_val_if_fail (TRACKER_IS_PROPERTY (property), NULL);
+
+	priv = GET_PRIV (property);
+
+	return priv->secondary_index;
+}
+
 gboolean
 tracker_property_get_fulltext_indexed (TrackerProperty *property)
 {
@@ -422,6 +442,18 @@ tracker_property_get_super_properties (TrackerProperty *property)
 	return (TrackerProperty **) priv->super_properties->data;
 }
 
+const gchar *
+tracker_property_get_default_value (TrackerProperty *property)
+{
+	TrackerPropertyPrivate *priv;
+
+	g_return_val_if_fail (TRACKER_IS_PROPERTY (property), NULL);
+
+	priv = GET_PRIV (property);
+
+	return priv->default_value;
+}
+
 void
 tracker_property_set_uri (TrackerProperty *property,
                           const gchar     *value)
@@ -497,6 +529,26 @@ tracker_property_set_domain (TrackerProperty *property,
 	}
 }
 
+void
+tracker_property_set_secondary_index (TrackerProperty *property,
+                                      TrackerProperty *value)
+{
+	TrackerPropertyPrivate *priv;
+
+	g_return_if_fail (TRACKER_IS_PROPERTY (property));
+
+	priv = GET_PRIV (property);
+
+	if (priv->secondary_index) {
+		g_object_unref (priv->secondary_index);
+		priv->secondary_index = NULL;
+	}
+
+	if (value) {
+		priv->secondary_index = g_object_ref (value);
+	}
+}
+
 void
 tracker_property_set_range (TrackerProperty *property,
                             TrackerClass     *value)
@@ -625,7 +677,7 @@ tracker_property_set_fulltext_indexed (TrackerProperty *property,
 
 void
 tracker_property_set_fulltext_no_limit (TrackerProperty *property,
-					gboolean         value)
+                                       gboolean          value)
 {
 	TrackerPropertyPrivate *priv;
 
@@ -693,3 +745,16 @@ tracker_property_add_super_property (TrackerProperty *property,
 	g_array_append_val (priv->super_properties, value);
 }
 
+void
+tracker_property_set_default_value (TrackerProperty *property,
+                                    const gchar     *value)
+{
+	TrackerPropertyPrivate *priv;
+
+	g_return_if_fail (TRACKER_IS_PROPERTY (property));
+
+	priv = GET_PRIV (property);
+
+	g_free (priv->default_value);
+	priv->default_value = g_strdup (value);
+}
