@@ -71,19 +71,19 @@ struct TrackerParser {
 	gint                   txt_size;
 
 	TrackerLanguage       *language;
+	guint                  max_word_length;
 	gboolean               enable_stemmer;
 	gboolean               enable_unaccent;
 	gboolean               ignore_stop_words;
-	guint                  max_word_length;
 	gboolean               ignore_reserved_words;
 	gboolean               ignore_numbers;
 
 	/* Private members */
-	gchar                   *word;
-	gint                    word_length;
-	guint                   word_position;
-	TrackerParserEncoding   encoding;
-	const gchar             *cursor;
+	gchar                 *word;
+	gint                   word_length;
+	guint                  word_position;
+	TrackerParserEncoding  encoding;
+	const gchar           *cursor;
 
 	/* Pango members for CJK text parsing */
 	PangoLogAttr          *attrs;
@@ -162,6 +162,90 @@ get_encoding (const gchar *txt)
 
 }
 
+static gchar *
+process_word_utf8 (TrackerParser *parser,
+		   const gchar   *word,
+		   gint           length,
+                   gboolean       do_strip,
+                   gboolean      *stop_word)
+{
+	gchar *stem_word;
+	gchar *str;
+	gchar *stripped_word;
+	gsize  bytes, len;
+
+	g_return_val_if_fail (parser != NULL, NULL);
+	g_return_val_if_fail (word != NULL, NULL);
+
+	str = NULL;
+	stripped_word = NULL;
+
+	if (word) {
+		if (length == -1) {
+			bytes = strlen (word);
+		} else {
+			bytes = length;
+		}
+
+		/* Log original word */
+		tracker_parser_message_hex ("ORIGINAL word",
+		                            word, bytes);
+
+		if (parser->enable_unaccent && do_strip) {
+			stripped_word = tracker_parser_unaccent_utf8_word (word,
+			                                                   bytes,
+			                                                   &len);
+
+			/* Log after UNAC stripping */
+			tracker_parser_message_hex (" After UNAC stripping",
+			                            stripped_word, len);
+		} else {
+			stripped_word = NULL;
+		}
+
+		if (!stripped_word) {
+			str = g_utf8_normalize (word,
+			                        bytes,
+			                        G_NORMALIZE_NFC);
+		} else {
+			str = g_utf8_normalize (stripped_word,
+			                        len,
+			                        G_NORMALIZE_NFC);
+			g_free (stripped_word);
+		}
+
+		/* Log after normalization */
+		tracker_parser_message_hex ("  After NFC normalization",
+		                            str, strlen ((gchar *)str));
+
+		if (!str) {
+			return NULL;
+		}
+
+		/* Check if stop word */
+		if (parser->ignore_stop_words) {
+			*stop_word = tracker_language_is_stop_word (parser->language,
+			                                            str);
+		}
+
+		if (!parser->enable_stemmer) {
+			return str;
+		}
+
+		len = strlen (str);
+
+		stem_word = tracker_language_stem_word (parser->language, str, len);
+
+		if (stem_word) {
+			g_free (str);
+
+			return stem_word;
+		}
+	}
+
+	return str;
+}
+
 static gboolean
 pango_next (TrackerParser *parser,
             gint          *byte_offset_start,
@@ -229,7 +313,8 @@ pango_next (TrackerParser *parser,
 static gboolean
 parser_next (TrackerParser *parser,
              gint          *byte_offset_start,
-             gint          *byte_offset_end)
+             gint          *byte_offset_end,
+             gboolean      *stop_word)
 {
 	TrackerParserWordType word_type;
 	gunichar              word[64];
@@ -400,7 +485,7 @@ parser_next (TrackerParser *parser,
 
 		parser->cursor = parser->txt + *byte_offset_end;
 
-		processed_word = tracker_parser_process_word (parser, utf8, bytes, do_strip);
+		processed_word = process_word_utf8 (parser, utf8, bytes, do_strip, stop_word);
 		g_free (utf8);
 
 		if (processed_word) {
@@ -413,26 +498,19 @@ parser_next (TrackerParser *parser,
 	}
 
 	return FALSE;
-
 }
 
 TrackerParser *
-tracker_parser_new (TrackerLanguage *language,
-                    gint             max_word_length)
+tracker_parser_new (TrackerLanguage *language)
 {
 	TrackerParser *parser;
 
 	g_return_val_if_fail (TRACKER_IS_LANGUAGE (language), NULL);
-	g_return_val_if_fail (max_word_length > 0, NULL);
 
 	parser = g_new0 (TrackerParser, 1);
 
 	parser->language = g_object_ref (language);
 
-	parser->max_word_length = max_word_length;
-	parser->word_length = 0;
-	parser->attrs = NULL;
-
 	return parser;
 }
 
@@ -456,6 +534,7 @@ void
 tracker_parser_reset (TrackerParser *parser,
                       const gchar   *txt,
                       gint           txt_size,
+                      guint          max_word_length,
                       gboolean       enable_stemmer,
                       gboolean       enable_unaccent,
                       gboolean       ignore_stop_words,
@@ -471,14 +550,15 @@ tracker_parser_reset (TrackerParser *parser,
 	parser->cursor = txt;
 	parser->encoding = get_encoding (txt);
 
+	parser->max_word_length = max_word_length;
 	parser->enable_stemmer = enable_stemmer;
 	parser->enable_unaccent = enable_unaccent;
 	parser->ignore_stop_words = ignore_stop_words;
+	parser->ignore_reserved_words = ignore_reserved_words;
+	parser->ignore_numbers = ignore_numbers;
 
 	parser->txt_size = txt_size;
 	parser->txt = txt;
-	parser->ignore_reserved_words = ignore_reserved_words;
-	parser->ignore_numbers = ignore_numbers;
 
 	g_free (parser->word);
 	parser->word = NULL;
@@ -508,83 +588,6 @@ tracker_parser_reset (TrackerParser *parser,
 	}
 }
 
-gchar *
-tracker_parser_process_word (TrackerParser *parser,
-                             const gchar   *word,
-                             gint           length,
-                             gboolean       do_strip)
-{
-	gchar *stem_word;
-	gchar *str;
-	gchar *stripped_word;
-	gsize  bytes, len;
-
-	g_return_val_if_fail (parser != NULL, NULL);
-	g_return_val_if_fail (word != NULL, NULL);
-
-	str = NULL;
-	stripped_word = NULL;
-
-	if (word) {
-		if (length == -1) {
-			bytes = strlen (word);
-		} else {
-			bytes = length;
-		}
-
-		/* Log original word */
-		tracker_parser_message_hex ("ORIGINAL word",
-		                            word, bytes);
-
-		if (parser->enable_unaccent && do_strip) {
-			stripped_word = tracker_parser_unaccent_utf8_word (word,
-			                                                   bytes,
-			                                                   &len);
-
-			/* Log after UNAC stripping */
-			tracker_parser_message_hex (" After UNAC stripping",
-			                            stripped_word, len);
-		} else {
-			stripped_word = NULL;
-		}
-
-		if (!stripped_word) {
-			str = g_utf8_normalize (word,
-			                        bytes,
-			                        G_NORMALIZE_NFC);
-		} else {
-			str = g_utf8_normalize (stripped_word,
-			                        len,
-			                        G_NORMALIZE_NFC);
-			g_free (stripped_word);
-		}
-
-		/* Log after normalization */
-		tracker_parser_message_hex ("  After NFC normalization",
-		                            str, strlen ((gchar *)str));
-
-		if (!str) {
-			return NULL;
-		}
-
-		if (!parser->enable_stemmer) {
-			return str;
-		}
-
-		len = strlen (str);
-
-		stem_word = tracker_language_stem_word (parser->language, str, len);
-
-		if (stem_word) {
-			g_free (str);
-
-			return stem_word;
-		}
-	}
-
-	return str;
-}
-
 const gchar *
 tracker_parser_next (TrackerParser *parser,
                      gint          *position,
@@ -594,33 +597,27 @@ tracker_parser_next (TrackerParser *parser,
                      gint          *word_length)
 {
 	const gchar  *str;
-	gint     byte_start = 0, byte_end = 0;
+	gint byte_start = 0, byte_end = 0;
 
 	str = NULL;
 
 	g_free (parser->word);
 	parser->word = NULL;
 
+	*stop_word = FALSE;
+
 	if (parser->encoding == TRACKER_PARSER_ENCODING_CJK) {
 		if (pango_next (parser, &byte_start, &byte_end)) {
 			str = parser->word;
 		}
-		parser->word_position++;
-
-		*stop_word = FALSE;
 	} else {
-		if (parser_next (parser, &byte_start, &byte_end)) {
+		if (parser_next (parser, &byte_start, &byte_end, stop_word)) {
 			str = parser->word;
 		}
+	}
 
-		if (str &&
-		    parser->ignore_stop_words &&
-		    tracker_language_is_stop_word (parser->language, str)) {
-			*stop_word = TRUE;
-		} else {
-			parser->word_position++;
-			*stop_word = FALSE;
-		}
+	if (!*stop_word) {
+		parser->word_position++;
 	}
 
 	*word_length = parser->word_length;
