@@ -44,6 +44,7 @@
 #include "tracker-marshal.h"
 
 #define DISK_SPACE_CHECK_FREQUENCY 10
+#define SECONDS_PER_DAY 60 * 60 * 24
 
 #define TRACKER_MINER_FILES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TRACKER_TYPE_MINER_FILES, TrackerMinerFilesPrivate))
 
@@ -160,6 +161,8 @@ static gboolean    miner_files_ignore_next_update_file  (TrackerMinerFS       *f
                                                          GFile                *file,
                                                          TrackerSparqlBuilder *sparql,
                                                          GCancellable         *cancellable);
+static void        miner_files_finished                 (TrackerMinerFS       *fs);
+
 static void      extractor_get_embedded_metadata_cancel (GCancellable    *cancellable,
                                                          ProcessFileData *data);
 
@@ -190,6 +193,7 @@ tracker_miner_files_class_init (TrackerMinerFilesClass *klass)
 	miner_fs_class->monitor_directory = miner_files_monitor_directory;
 	miner_fs_class->process_file = miner_files_process_file;
 	miner_fs_class->ignore_next_update_file = miner_files_ignore_next_update_file;
+        miner_fs_class->finished = miner_files_finished;
 
 	g_object_class_install_property (object_class,
 	                                 PROP_CONFIG,
@@ -592,7 +596,7 @@ set_up_mount_point (TrackerMinerFiles *miner,
 			                        removable_device_urn, removable_device_urn, uri);
 
 			g_string_append_printf (queries,
-			                        "DROP GRAPH <%s> "
+			                        "DELETE { <%s> a rdfs:Resource }  "
 			                        "INSERT INTO <%s> { "
 			                        "  <%s> a tracker:Volume; "
 			                        "       tracker:mountPoint ?u "
@@ -930,7 +934,7 @@ check_battery_status (TrackerMinerFiles *mf)
 			if (!tracker_config_get_index_on_battery_first_time (mf->private->config)) {
 				g_message ("Running on battery, but not enabled, pausing");
 				should_pause = TRUE;
-			} else if (tracker_db_manager_get_first_index_done()) {
+			} else if (tracker_db_manager_get_first_index_done ()) {
 				g_message ("Running on battery and first-time index "
 				           "already done, pausing");
 				should_pause = TRUE;
@@ -1306,8 +1310,6 @@ miner_files_check_directory (TrackerMinerFS *fs,
 	                                            tracker_config_get_index_single_directories (mf->private->config),
 	                                            tracker_config_get_ignored_directory_paths (mf->private->config),
 	                                            tracker_config_get_ignored_directory_patterns (mf->private->config));
-
-
 }
 
 static gboolean
@@ -1603,7 +1605,7 @@ process_file_cb (GObject      *object,
 	mime_type = g_file_info_get_content_type (file_info);
 	urn = miner_files_get_file_urn (TRACKER_MINER_FILES (data->miner), file, &is_iri);
 
-	tracker_sparql_builder_insert_open (sparql, uri);
+	tracker_sparql_builder_insert_silent_open (sparql, TRACKER_MINER_FS_GRAPH_URN);
 
 	if (is_iri) {
 		tracker_sparql_builder_subject_iri (sparql, urn);
@@ -1734,7 +1736,7 @@ miner_files_ignore_next_update_file (TrackerMinerFS       *fs,
 	 * should NEVER be marked as tracker:writeback in the ontology! (else you break
 	 * the tracker-writeback feature) */
 
-	tracker_sparql_builder_insert_open (sparql, uri);
+	tracker_sparql_builder_insert_silent_open (sparql, TRACKER_MINER_FS_GRAPH_URN);
 
 	tracker_sparql_builder_subject_variable (sparql, "urn");
 	tracker_sparql_builder_predicate (sparql, "a");
@@ -1770,6 +1772,47 @@ miner_files_ignore_next_update_file (TrackerMinerFS       *fs,
 	return TRUE;
 }
 
+static gboolean
+should_check_mtime (TrackerConfig *config)
+{
+	gint crawling_interval;
+
+	crawling_interval = tracker_config_get_crawling_interval (config);
+
+	g_message ("Checking whether to perform mtime checks during crawling:");
+
+	if (crawling_interval == -1) {
+		g_message ("  Disabled");
+		return FALSE;
+	} else if (crawling_interval == 0) {
+		g_message ("  Enabled");
+		return TRUE;
+	} else {
+		guint64 then, now;
+
+		then = tracker_db_manager_get_last_crawl_done ();
+		if (then < 1) {
+			g_message ("  No previous timestamp, crawling forced");
+			return TRUE;
+		}
+	
+		now = (guint64) time (NULL);
+
+		if (now < then + (crawling_interval * SECONDS_PER_DAY)) {
+			g_message ("  Postponed");
+			return FALSE;
+		} else {
+			g_message ("Not occurred for %d days, crawling forced", crawling_interval);
+			return FALSE;
+		}
+	}
+}
+
+static void
+miner_files_finished (TrackerMinerFS *fs)
+{
+        tracker_db_manager_set_last_crawl_done (TRUE);
+}
 
 TrackerMiner *
 tracker_miner_files_new (TrackerConfig *config)
@@ -1778,6 +1821,7 @@ tracker_miner_files_new (TrackerConfig *config)
 	                     "name", "Files",
 	                     "config", config,
 	                     "process-pool-limit", 10,
+	                     "mtime-checking", should_check_mtime (config),
 	                     NULL);
 }
 
