@@ -51,6 +51,7 @@ const TestInfo tests[] = {
 	{ "algebra/filter-placement-1", "algebra/data-2", FALSE },
 	{ "algebra/filter-placement-2", "algebra/data-2", FALSE },
 	{ "algebra/filter-placement-3", "algebra/data-2", FALSE },
+	{ "algebra/filter-placement-3a", "algebra/data-2", FALSE },
 	{ "algebra/filter-nested-1", "algebra/data-1", FALSE },
 	{ "algebra/filter-nested-2", "algebra/data-1", FALSE },
 	{ "algebra/filter-scope-1", "algebra/data-2", FALSE },
@@ -75,6 +76,7 @@ const TestInfo tests[] = {
 	{ "expr-ops/query-plus-1", "expr-ops/data", FALSE },
 	{ "expr-ops/query-unminus-1", "expr-ops/data", FALSE },
 	{ "expr-ops/query-unplus-1", "expr-ops/data", FALSE },
+	{ "expr-ops/query-res-1", "expr-ops/data", FALSE },
 	{ "functions/functions-property-1", "functions/data-1", FALSE },
 	{ "functions/functions-tracker-1", "functions/data-1", FALSE },
 	{ "functions/functions-tracker-2", "functions/data-2", FALSE },
@@ -88,6 +90,7 @@ const TestInfo tests[] = {
 	{ "graph/graph-1", "graph/data-1", FALSE },
 	{ "graph/graph-2", "graph/data-2", FALSE },
 	{ "graph/graph-3", "graph/data-3", FALSE },
+	{ "graph/graph-4", "graph/data-3", FALSE },
 	{ "optional/q-opt-complex-1", "optional/complex-data-1", FALSE },
 	{ "regex/regex-query-001", "regex/regex-data-01", FALSE },
 	{ "regex/regex-query-002", "regex/regex-data-01", FALSE },
@@ -98,6 +101,7 @@ const TestInfo tests[] = {
 	{ "sort/query-sort-5", "sort/data-sort-4", FALSE },
 	{ "subqueries/subqueries-1", "subqueries/data-1", FALSE },
 	{ "subqueries/subqueries-union-1", "subqueries/data-1", FALSE },
+	{ "subqueries/subqueries-union-2", "subqueries/data-1", FALSE },
 	/* Bracket error after WHERE */
 	{ "error/query-error-1", "error/query-error-1", TRUE, FALSE },
 	/* Unknown property */
@@ -350,7 +354,7 @@ main (int argc, char **argv)
 
 	/* clean up */
 	g_print ("Removing temporary data\n");
-	g_spawn_command_line_async ("rm -R tracker/", NULL);
+	g_spawn_command_line_sync ("rm -R tracker/", NULL, NULL, NULL, NULL);
 
 	return result;
 }
